# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing_extensions import Literal, TypeAlias

__all__ = ["RunsFilterDataSourceTypeEnum"]

RunsFilterDataSourceTypeEnum: TypeAlias = Literal[
    "current", "historical", "lite", "root_lite", "runs_feedbacks_rmt_wide"
]
